==> ZMS3-3.2.4.tar.gz: ZMS3-3.2.4/_ziputil.py <==
################################################################################
# _ziputil.py
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
################################################################################

# Imports.
from cStringIO import StringIO
from types import StringTypes
import os
import tempfile
import zipfile
# Product Imports.
import _globals


"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
_ziputil.exportZodb2Zip:

Extracts and imports zip-file to zodb.
"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
def _exportZodb2Zip(zf, root, container):
  for ob in container.objectValues():
    if ob.meta_type in ['Folder']:
      _exportZodb2Zip(zf,root,ob)
    elif ob.meta_type in ['Image','File']:
      arcname = ob.absolute_url()[len(root.absolute_url())+1:]
      print "_exportZodb2Zip",arcname
      try:
        bytes = ob.data
        if len(bytes) == 0:
          bytes = ob.getData()
        try:
          bytes = bytes.read()
        except:
          bytes = str(bytes)
        zf.writestr(arcname,bytes)
      except:
        _globals.writeError(root.content,"_exportZodb2Zip")

def exportZodb2Zip(root):
  # Create temporary zip-file.
  zipfilename = tempfile.mktemp() + '.zip'
  zf = zipfile.ZipFile( zipfilename, 'w')
  _exportZodb2Zip(zf,root,root)
  zf.close()
  
  # Read data from zip-file as return value.
  f = open( zipfilename, 'rb')
  data = f.read()
  f.close()
  
  # Remove temporary zip-file.
  os.remove( zipfilename)
  
  # Returns data of zip-file.
  print len(data)
  return data


"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
_ziputil.importZip2Zodb:

Extracts and imports zip-file to zodb.
"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
def importZip2Zodb(root, data):
  if type( data) in StringTypes:
    data = StringIO( data)
  zf = zipfile.ZipFile( data, 'r')
  for name in zf.namelist():
    container = root
    ids = map(lambda x:str(x),name.split('/'))
    if len(ids) > 1:
      for id in ids[:-1]:
        if id not in container.objectIds():
          container.manage_addFolder(id=id)
        container = getattr(container,id)
    id = ids[-1]
    if id:
      file = zf.read( name)
      mt, enc  = _globals.guess_contenttype( id, file)
      if id in container.objectIds():
        container.manage_delObjects( [id])
      if mt.startswith('image'):
        file = container.manage_addImage(id=id,file=file)
      else:
        file = container.manage_addFile(id=id,file=file)

################################################################################

==> ZMS-3.5.0.tar.gz: ZMS-3.5.0/_ziputil.py <==
# -*- coding: utf-8 -*- 
################################################################################
# _ziputil.py
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
################################################################################

# Imports.
from cStringIO import StringIO
import os
import tempfile
import zipfile
# Product Imports.
import standard
import _globals


"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
_ziputil.exportZodb2Zip:

Extracts and imports zip-file to zodb.
"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
def _exportZodb2Zip(zf, root, container):
  for ob in container.objectValues():
    if ob.meta_type in ['Folder']:
      _exportZodb2Zip(zf,root,ob)
    elif ob.meta_type in ['Image','File']:
      arcname = ob.absolute_url()[len(root.absolute_url())+1:]
      try:
        bytes = ob.data
        if len(bytes) == 0:
          bytes = ob.getData()
        try:
          bytes = bytes.read()
        except:
          bytes = str(bytes)
        zf.writestr(arcname,bytes)
      except:
        standard.writeError(root.content,"_exportZodb2Zip")

def exportZodb2Zip(root):
  # Create temporary zip-file.
  zipfilename = tempfile.mktemp() + '.zip'
  zf = zipfile.ZipFile( zipfilename, 'w')
  _exportZodb2Zip(zf,root,root)
  zf.close()
  
  # Read data from zip-file as return value.
  f = open( zipfilename, 'rb')
  data = f.read()
  f.close()
  
  # Remove temporary zip-file.
  os.remove( zipfilename)
  
  # Returns data of zip-file.
  return data


"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
_ziputil.importZip2Zodb:

Extracts and imports zip-file to zodb.
"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
def importZip2Zodb(root, data):
  if _globals.is_str_type(data):
    data = StringIO( data)
  zf = zipfile.ZipFile( data, 'r')
  for name in zf.namelist():
    container = root
    ids = map(lambda x:str(x),name.split('/'))
    if len(ids) > 1:
      for id in ids[:-1]:
        if id not in container.objectIds():
          container.manage_addFolder(id=id)
        container = getattr(container,id)
    id = ids[-1]
    if id:
      file = zf.read( name)
      mt, enc  = standard.guess_content_type( id, file)
      if id in container.objectIds():
        container.manage_delObjects( [id])
      if mt.startswith('image'):
        file = container.manage_addImage(id=id,file=file)
      else:
        file = container.manage_addFile(id=id,file=file)

################################################################################
